package sun.swing.plaf.synth;

import java.awt.Container;
import java.awt.LayoutManager;
import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Arrays;
import sun.awt.shell.ShellFolder;
import java.util.Vector;
import javax.swing.AbstractListModel;
import java.awt.Graphics;
import javax.swing.Icon;
import java.awt.Component;
import javax.swing.ListCellRenderer;
import javax.swing.event.ListSelectionListener;
import javax.swing.plaf.basic.BasicDirectoryModel;
import java.awt.event.MouseListener;
import javax.swing.JList;
import javax.swing.plaf.ActionMapUIResource;
import javax.swing.ActionMap;
import javax.swing.ComboBoxModel;
import sun.swing.SwingUtilities2;
import java.util.Locale;
import javax.swing.JComponent;
import javax.swing.filechooser.FileSystemView;
import javax.swing.JPopupMenu;
import java.awt.event.FocusEvent;
import java.awt.event.FocusAdapter;
import javax.swing.ButtonGroup;
import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.BoxLayout;
import java.awt.BorderLayout;
import javax.swing.UIManager;
import java.beans.PropertyChangeEvent;
import javax.swing.JFileChooser;
import java.beans.PropertyChangeListener;
import java.awt.Insets;
import java.awt.Dimension;
import javax.swing.filechooser.FileFilter;
import javax.swing.JPanel;
import javax.swing.JToggleButton;
import sun.swing.FilePane;
import javax.swing.JTextField;
import javax.swing.Action;
import java.io.File;
import javax.swing.JComboBox;
import javax.swing.JLabel;

public class SynthFileChooserUIImpl extends SynthFileChooserUI
{
    private JLabel lookInLabel;
    private JComboBox<File> directoryComboBox;
    private SynthFileChooserUIImpl.DirectoryComboBoxModel directoryComboBoxModel;
    private Action directoryComboBoxAction;
    private SynthFileChooserUIImpl.FilterComboBoxModel filterComboBoxModel;
    private JTextField fileNameTextField;
    private FilePane filePane;
    private JToggleButton listViewButton;
    private JToggleButton detailsViewButton;
    private boolean readOnly;
    private JPanel buttonPanel;
    private JPanel bottomPanel;
    private JComboBox<FileFilter> filterComboBox;
    private static final Dimension hstrut5;
    private static final Insets shrinkwrap;
    private static Dimension LIST_PREF_SIZE;
    private int lookInLabelMnemonic;
    private String lookInLabelText;
    private String saveInLabelText;
    private int fileNameLabelMnemonic;
    private String fileNameLabelText;
    private int folderNameLabelMnemonic;
    private String folderNameLabelText;
    private int filesOfTypeLabelMnemonic;
    private String filesOfTypeLabelText;
    private String upFolderToolTipText;
    private String upFolderAccessibleName;
    private String homeFolderToolTipText;
    private String homeFolderAccessibleName;
    private String newFolderToolTipText;
    private String newFolderAccessibleName;
    private String listViewButtonToolTipText;
    private String listViewButtonAccessibleName;
    private String detailsViewButtonToolTipText;
    private String detailsViewButtonAccessibleName;
    private SynthFileChooserUIImpl.AlignedLabel fileNameLabel;
    private final PropertyChangeListener modeListener;
    static final int space = 10;
    
    private void populateFileNameLabel() {
        if (this.getFileChooser().getFileSelectionMode() == 1) {
            this.fileNameLabel.setText(this.folderNameLabelText);
            this.fileNameLabel.setDisplayedMnemonic(this.folderNameLabelMnemonic);
        }
        else {
            this.fileNameLabel.setText(this.fileNameLabelText);
            this.fileNameLabel.setDisplayedMnemonic(this.fileNameLabelMnemonic);
        }
    }
    
    public SynthFileChooserUIImpl(JFileChooser fileChooser) {
        super(fileChooser);
        this.directoryComboBoxAction = new SynthFileChooserUIImpl.DirectoryComboBoxAction();
        this.lookInLabelMnemonic = 0;
        this.lookInLabelText = null;
        this.saveInLabelText = null;
        this.fileNameLabelMnemonic = 0;
        this.fileNameLabelText = null;
        this.folderNameLabelMnemonic = 0;
        this.folderNameLabelText = null;
        this.filesOfTypeLabelMnemonic = 0;
        this.filesOfTypeLabelText = null;
        this.upFolderToolTipText = null;
        this.upFolderAccessibleName = null;
        this.homeFolderToolTipText = null;
        this.homeFolderAccessibleName = null;
        this.newFolderToolTipText = null;
        this.newFolderAccessibleName = null;
        this.listViewButtonToolTipText = null;
        this.listViewButtonAccessibleName = null;
        this.detailsViewButtonToolTipText = null;
        this.detailsViewButtonAccessibleName = null;
        this.modeListener = new PropertyChangeListener() {
            @Override
            public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
                if (SynthFileChooserUIImpl.this.fileNameLabel != null) {
                    SynthFileChooserUIImpl.access$100(SynthFileChooserUIImpl.this);
                }
            }
        };
    }
    
    @Override
    protected void installDefaults(JFileChooser fileChooser) {
        super.installDefaults(fileChooser);
        this.readOnly = UIManager.getBoolean("FileChooser.readOnly");
    }
    
    @Override
    public void installComponents(JFileChooser fileChooser) {
        super.installComponents(fileChooser);
        this.getContext(fileChooser, 1);
        fileChooser.setLayout(new BorderLayout(0, 11));
        JPanel comp = new JPanel(new BorderLayout(11, 0));
        JPanel panel = new JPanel();
        panel.setLayout(new BoxLayout(panel, 2));
        comp.add(panel, "After");
        fileChooser.add(comp, "North");
        (this.lookInLabel = new JLabel(this.lookInLabelText)).setDisplayedMnemonic(this.lookInLabelMnemonic);
        comp.add(this.lookInLabel, "Before");
        this.directoryComboBox = new JComboBox();
        this.directoryComboBox.getAccessibleContext().setAccessibleDescription(this.lookInLabelText);
        this.directoryComboBox.putClientProperty("JComboBox.isTableCellEditor", Boolean.TRUE);
        this.lookInLabel.setLabelFor(this.directoryComboBox);
        this.directoryComboBoxModel = this.createDirectoryComboBoxModel(fileChooser);
        this.directoryComboBox.setModel(this.directoryComboBoxModel);
        this.directoryComboBox.addActionListener(this.directoryComboBoxAction);
        this.directoryComboBox.setRenderer(this.createDirectoryComboBoxRenderer(fileChooser));
        this.directoryComboBox.setAlignmentX(0.0f);
        this.directoryComboBox.setAlignmentY(0.0f);
        this.directoryComboBox.setMaximumRowCount(8);
        comp.add(this.directoryComboBox, "Center");
        fileChooser.addPropertyChangeListener(this.filePane = new FilePane(new SynthFileChooserUIImpl.SynthFileChooserUIAccessor()));
        JPopupMenu componentPopupMenu = this.filePane.getComponentPopupMenu();
        if (componentPopupMenu != null) {
            componentPopupMenu.insert(this.getChangeToParentDirectoryAction(), 0);
            if (File.separatorChar == '/') {
                componentPopupMenu.insert(this.getGoHomeAction(), 1);
            }
        }
        FileSystemView fileSystemView = fileChooser.getFileSystemView();
        JButton comp2 = new JButton(this.getChangeToParentDirectoryAction());
        comp2.setText(null);
        comp2.setIcon(this.upFolderIcon);
        comp2.setToolTipText(this.upFolderToolTipText);
        comp2.getAccessibleContext().setAccessibleName(this.upFolderAccessibleName);
        comp2.setAlignmentX(0.0f);
        comp2.setAlignmentY(0.5f);
        comp2.setMargin(SynthFileChooserUIImpl.shrinkwrap);
        panel.add(comp2);
        panel.add(Box.createRigidArea(SynthFileChooserUIImpl.hstrut5));
        fileSystemView.getHomeDirectory();
        String homeFolderToolTipText = this.homeFolderToolTipText;
        JButton comp3 = new JButton(this.homeFolderIcon);
        comp3.setToolTipText(homeFolderToolTipText);
        comp3.getAccessibleContext().setAccessibleName(this.homeFolderAccessibleName);
        comp3.setAlignmentX(0.0f);
        comp3.setAlignmentY(0.5f);
        comp3.setMargin(SynthFileChooserUIImpl.shrinkwrap);
        comp3.addActionListener(this.getGoHomeAction());
        panel.add(comp3);
        panel.add(Box.createRigidArea(SynthFileChooserUIImpl.hstrut5));
        if (!this.readOnly) {
            JButton comp4 = new JButton(this.filePane.getNewFolderAction());
            comp4.setText(null);
            comp4.setIcon(this.newFolderIcon);
            comp4.setToolTipText(this.newFolderToolTipText);
            comp4.getAccessibleContext().setAccessibleName(this.newFolderAccessibleName);
            comp4.setAlignmentX(0.0f);
            comp4.setAlignmentY(0.5f);
            comp4.setMargin(SynthFileChooserUIImpl.shrinkwrap);
            panel.add(comp4);
            panel.add(Box.createRigidArea(SynthFileChooserUIImpl.hstrut5));
        }
        ButtonGroup o = new ButtonGroup();
        (this.listViewButton = new JToggleButton(this.listViewIcon)).setToolTipText(this.listViewButtonToolTipText);
        this.listViewButton.getAccessibleContext().setAccessibleName(this.listViewButtonAccessibleName);
        this.listViewButton.setSelected(true);
        this.listViewButton.setAlignmentX(0.0f);
        this.listViewButton.setAlignmentY(0.5f);
        this.listViewButton.setMargin(SynthFileChooserUIImpl.shrinkwrap);
        this.listViewButton.addActionListener(this.filePane.getViewTypeAction(0));
        panel.add(this.listViewButton);
        o.add(this.listViewButton);
        (this.detailsViewButton = new JToggleButton(this.detailsViewIcon)).setToolTipText(this.detailsViewButtonToolTipText);
        this.detailsViewButton.getAccessibleContext().setAccessibleName(this.detailsViewButtonAccessibleName);
        this.detailsViewButton.setAlignmentX(0.0f);
        this.detailsViewButton.setAlignmentY(0.5f);
        this.detailsViewButton.setMargin(SynthFileChooserUIImpl.shrinkwrap);
        this.detailsViewButton.addActionListener(this.filePane.getViewTypeAction(1));
        panel.add(this.detailsViewButton);
        o.add(this.detailsViewButton);
        this.filePane.addPropertyChangeListener(new PropertyChangeListener() {
            @Override
            public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
                if ("viewType".equals(propertyChangeEvent.getPropertyName())) {
                    switch (SynthFileChooserUIImpl.this.filePane.getViewType()) {
                        case 0: {
                            SynthFileChooserUIImpl.this.listViewButton.setSelected(true);
                            break;
                        }
                        case 1: {
                            SynthFileChooserUIImpl.this.detailsViewButton.setSelected(true);
                            break;
                        }
                    }
                }
            }
        });
        fileChooser.add(this.getAccessoryPanel(), "After");
        JComponent accessory = fileChooser.getAccessory();
        if (accessory != null) {
            this.getAccessoryPanel().add(accessory);
        }
        this.filePane.setPreferredSize(SynthFileChooserUIImpl.LIST_PREF_SIZE);
        fileChooser.add(this.filePane, "Center");
        (this.bottomPanel = new JPanel()).setLayout(new BoxLayout(this.bottomPanel, 1));
        fileChooser.add(this.bottomPanel, "South");
        JPanel o2 = new JPanel();
        o2.setLayout(new BoxLayout(o2, 2));
        this.bottomPanel.add(o2);
        this.bottomPanel.add(Box.createRigidArea(new Dimension(1, 5)));
        this.fileNameLabel = new SynthFileChooserUIImpl.AlignedLabel();
        this.populateFileNameLabel();
        o2.add(this.fileNameLabel);
        o2.add(this.fileNameTextField = new JTextField(35) {
            @Override
            public Dimension getMaximumSize() {
                return new Dimension(32767, super.getPreferredSize().height);
            }
        });
        this.fileNameLabel.setLabelFor(this.fileNameTextField);
        this.fileNameTextField.addFocusListener(new FocusAdapter() {
            @Override
            public void focusGained(FocusEvent focusEvent) {
                if (!SynthFileChooserUIImpl.this.getFileChooser().isMultiSelectionEnabled()) {
                    SynthFileChooserUIImpl.this.filePane.clearSelection();
                }
            }
        });
        if (fileChooser.isMultiSelectionEnabled()) {
            this.setFileName(this.fileNameString(fileChooser.getSelectedFiles()));
        }
        else {
            this.setFileName(this.fileNameString(fileChooser.getSelectedFile()));
        }
        JPanel o3 = new JPanel();
        o3.setLayout(new BoxLayout(o3, 2));
        this.bottomPanel.add(o3);
        SynthFileChooserUIImpl.AlignedLabel comp5 = new SynthFileChooserUIImpl.AlignedLabel(this.filesOfTypeLabelText);
        comp5.setDisplayedMnemonic(this.filesOfTypeLabelMnemonic);
        o3.add(comp5);
        fileChooser.addPropertyChangeListener(this.filterComboBoxModel = this.createFilterComboBoxModel());
        this.filterComboBox = new JComboBox(this.filterComboBoxModel);
        this.filterComboBox.getAccessibleContext().setAccessibleDescription(this.filesOfTypeLabelText);
        comp5.setLabelFor(this.filterComboBox);
        this.filterComboBox.setRenderer(this.createFilterComboBoxRenderer());
        o3.add(this.filterComboBox);
        (this.buttonPanel = new JPanel()).setLayout(new SynthFileChooserUIImpl.ButtonAreaLayout());
        this.buttonPanel.add(this.getApproveButton(fileChooser));
        this.buttonPanel.add(this.getCancelButton(fileChooser));
        if (fileChooser.getControlButtonsAreShown()) {
            this.addControlButtons();
        }
        groupLabels(new SynthFileChooserUIImpl.AlignedLabel[] { this.fileNameLabel, comp5 });
    }
    
    @Override
    protected void installListeners(JFileChooser fileChooser) {
        super.installListeners(fileChooser);
        fileChooser.addPropertyChangeListener("fileSelectionChanged", this.modeListener);
    }
    
    @Override
    protected void uninstallListeners(JFileChooser fc) {
        fc.removePropertyChangeListener("fileSelectionChanged", this.modeListener);
        super.uninstallListeners(fc);
    }
    
    private String fileNameString(File file) {
        if (file == null) {
            return null;
        }
        JFileChooser fileChooser = this.getFileChooser();
        if (fileChooser.isDirectorySelectionEnabled() && !fileChooser.isFileSelectionEnabled()) {
            return file.getPath();
        }
        return file.getName();
    }
    
    private String fileNameString(File[] array) {
        StringBuffer sb = new StringBuffer();
        for (int n = 0; array != null && n < array.length; ++n) {
            if (n > 0) {
                sb.append(" ");
            }
            if (array.length > 1) {
                sb.append("\"");
            }
            sb.append(this.fileNameString(array[n]));
            if (array.length > 1) {
                sb.append("\"");
            }
        }
        return sb.toString();
    }
    
    @Override
    public void uninstallUI(JComponent c) {
        c.removePropertyChangeListener(this.filterComboBoxModel);
        c.removePropertyChangeListener(this.filePane);
        if (this.filePane != null) {
            this.filePane.uninstallUI();
            this.filePane = null;
        }
        super.uninstallUI(c);
    }
    
    @Override
    protected void installStrings(JFileChooser fc) {
        super.installStrings(fc);
        Locale locale = fc.getLocale();
        this.lookInLabelMnemonic = this.getMnemonic("FileChooser.lookInLabelMnemonic", locale);
        this.lookInLabelText = UIManager.getString("FileChooser.lookInLabelText", locale);
        this.saveInLabelText = UIManager.getString("FileChooser.saveInLabelText", locale);
        this.fileNameLabelMnemonic = this.getMnemonic("FileChooser.fileNameLabelMnemonic", locale);
        this.fileNameLabelText = UIManager.getString("FileChooser.fileNameLabelText", locale);
        this.folderNameLabelMnemonic = this.getMnemonic("FileChooser.folderNameLabelMnemonic", locale);
        this.folderNameLabelText = UIManager.getString("FileChooser.folderNameLabelText", locale);
        this.filesOfTypeLabelMnemonic = this.getMnemonic("FileChooser.filesOfTypeLabelMnemonic", locale);
        this.filesOfTypeLabelText = UIManager.getString("FileChooser.filesOfTypeLabelText", locale);
        this.upFolderToolTipText = UIManager.getString("FileChooser.upFolderToolTipText", locale);
        this.upFolderAccessibleName = UIManager.getString("FileChooser.upFolderAccessibleName", locale);
        this.homeFolderToolTipText = UIManager.getString("FileChooser.homeFolderToolTipText", locale);
        this.homeFolderAccessibleName = UIManager.getString("FileChooser.homeFolderAccessibleName", locale);
        this.newFolderToolTipText = UIManager.getString("FileChooser.newFolderToolTipText", locale);
        this.newFolderAccessibleName = UIManager.getString("FileChooser.newFolderAccessibleName", locale);
        this.listViewButtonToolTipText = UIManager.getString("FileChooser.listViewButtonToolTipText", locale);
        this.listViewButtonAccessibleName = UIManager.getString("FileChooser.listViewButtonAccessibleName", locale);
        this.detailsViewButtonToolTipText = UIManager.getString("FileChooser.detailsViewButtonToolTipText", locale);
        this.detailsViewButtonAccessibleName = UIManager.getString("FileChooser.detailsViewButtonAccessibleName", locale);
    }
    
    private int getMnemonic(String key, Locale l) {
        return SwingUtilities2.getUIDefaultsInt(key, l);
    }
    
    @Override
    public String getFileName() {
        if (this.fileNameTextField != null) {
            return this.fileNameTextField.getText();
        }
        return null;
    }
    
    @Override
    public void setFileName(String text) {
        if (this.fileNameTextField != null) {
            this.fileNameTextField.setText(text);
        }
    }
    
    @Override
    public void rescanCurrentDirectory(JFileChooser fileChooser) {
        this.filePane.rescanCurrentDirectory();
    }
    
    @Override
    protected void doSelectedFileChanged(PropertyChangeEvent propertyChangeEvent) {
        super.doSelectedFileChanged(propertyChangeEvent);
        File file = (File)propertyChangeEvent.getNewValue();
        JFileChooser fileChooser = this.getFileChooser();
        if (file != null && ((fileChooser.isFileSelectionEnabled() && !file.isDirectory()) || (file.isDirectory() && fileChooser.isDirectorySelectionEnabled()))) {
            this.setFileName(this.fileNameString(file));
        }
    }
    
    @Override
    protected void doSelectedFilesChanged(PropertyChangeEvent propertyChangeEvent) {
        super.doSelectedFilesChanged(propertyChangeEvent);
        File[] array = (File[])(File[])propertyChangeEvent.getNewValue();
        JFileChooser fileChooser = this.getFileChooser();
        if (array != null && array.length > 0 && (array.length > 1 || fileChooser.isDirectorySelectionEnabled() || !array[0].isDirectory())) {
            this.setFileName(this.fileNameString(array));
        }
    }
    
    @Override
    protected void doDirectoryChanged(PropertyChangeEvent propertyChangeEvent) {
        super.doDirectoryChanged(propertyChangeEvent);
        JFileChooser fileChooser = this.getFileChooser();
        FileSystemView fileSystemView = fileChooser.getFileSystemView();
        File currentDirectory = fileChooser.getCurrentDirectory();
        if (!this.readOnly && currentDirectory != null) {
            this.getNewFolderAction().setEnabled(this.filePane.canWrite(currentDirectory));
        }
        if (currentDirectory != null) {
            JComponent directoryComboBox = this.getDirectoryComboBox();
            if ((directoryComboBox instanceof JComboBox)) {
                ComboBoxModel<Object> model = ((JComboBox)directoryComboBox).getModel();
                if ((model instanceof SynthFileChooserUIImpl.DirectoryComboBoxModel)) {
                    ((SynthFileChooserUIImpl.DirectoryComboBoxModel)model).addItem(currentDirectory);
                }
            }
            if (fileChooser.isDirectorySelectionEnabled() && !fileChooser.isFileSelectionEnabled()) {
                if (fileSystemView.isFileSystem(currentDirectory)) {
                    this.setFileName(currentDirectory.getPath());
                }
                else {
                    this.setFileName(null);
                }
            }
        }
    }
    
    @Override
    protected void doFileSelectionModeChanged(PropertyChangeEvent propertyChangeEvent) {
        super.doFileSelectionModeChanged(propertyChangeEvent);
        JFileChooser fileChooser = this.getFileChooser();
        File currentDirectory = fileChooser.getCurrentDirectory();
        if (currentDirectory != null && fileChooser.isDirectorySelectionEnabled() && !fileChooser.isFileSelectionEnabled() && fileChooser.getFileSystemView().isFileSystem(currentDirectory)) {
            this.setFileName(currentDirectory.getPath());
        }
        else {
            this.setFileName(null);
        }
    }
    
    @Override
    protected void doAccessoryChanged(PropertyChangeEvent propertyChangeEvent) {
        if (this.getAccessoryPanel() != null) {
            if (propertyChangeEvent.getOldValue() != null) {
                this.getAccessoryPanel().remove((JComponent)propertyChangeEvent.getOldValue());
            }
            JComponent comp = (JComponent)propertyChangeEvent.getNewValue();
            if (comp != null) {
                this.getAccessoryPanel().add(comp, "Center");
            }
        }
    }
    
    @Override
    protected void doControlButtonsChanged(PropertyChangeEvent propertyChangeEvent) {
        super.doControlButtonsChanged(propertyChangeEvent);
        if (this.getFileChooser().getControlButtonsAreShown()) {
            this.addControlButtons();
        }
        else {
            this.removeControlButtons();
        }
    }
    
    protected void addControlButtons() {
        if (this.bottomPanel != null) {
            this.bottomPanel.add(this.buttonPanel);
        }
    }
    
    protected void removeControlButtons() {
        if (this.bottomPanel != null) {
            this.bottomPanel.remove(this.buttonPanel);
        }
    }
    
    @Override
    protected ActionMap createActionMap() {
        ActionMapUIResource map = new ActionMapUIResource();
        FilePane.addActionsToMap(map, this.filePane.getActions());
        map.put("fileNameCompletion", this.getFileNameCompletionAction());
        return map;
    }
    
    protected JComponent getDirectoryComboBox() {
        return this.directoryComboBox;
    }
    
    protected Action getDirectoryComboBoxAction() {
        return this.directoryComboBoxAction;
    }
    
    protected SynthFileChooserUIImpl.DirectoryComboBoxRenderer createDirectoryComboBoxRenderer(JFileChooser fileChooser) {
        return new SynthFileChooserUIImpl.DirectoryComboBoxRenderer(this.directoryComboBox.getRenderer());
    }
    
    protected SynthFileChooserUIImpl.DirectoryComboBoxModel createDirectoryComboBoxModel(JFileChooser fileChooser) {
        return new SynthFileChooserUIImpl.DirectoryComboBoxModel();
    }
    
    protected SynthFileChooserUIImpl.FilterComboBoxRenderer createFilterComboBoxRenderer() {
        return new SynthFileChooserUIImpl.FilterComboBoxRenderer(this.filterComboBox.getRenderer());
    }
    
    protected SynthFileChooserUIImpl.FilterComboBoxModel createFilterComboBoxModel() {
        return new SynthFileChooserUIImpl.FilterComboBoxModel();
    }
    
    private static void groupLabels(SynthFileChooserUIImpl.AlignedLabel[] array) {
        for (int i = 0; i < array.length; ++i) {
            array[i].group = array;
        }
    }
    
    static void access$100(SynthFileChooserUIImpl synthFileChooserUIImpl) {
        synthFileChooserUIImpl.populateFileNameLabel();
    }
    
    static boolean access$200(SynthFileChooserUIImpl synthFileChooserUIImpl) {
        return synthFileChooserUIImpl.isDirectorySelected();
    }
    
    static File access$300(SynthFileChooserUIImpl synthFileChooserUIImpl) {
        return synthFileChooserUIImpl.getDirectory();
    }
    
    static MouseListener access$400(SynthFileChooserUIImpl synthFileChooserUIImpl, JFileChooser fc, JList list) {
        return synthFileChooserUIImpl.createDoubleClickListener(fc, list);
    }
    
    static {
        hstrut5 = new Dimension(5, 1);
        shrinkwrap = new Insets(0, 0, 0, 0);
        SynthFileChooserUIImpl.LIST_PREF_SIZE = new Dimension(405, 135);
    }
    
    private class SynthFileChooserUIAccessor implements FilePane.FileChooserUIAccessor
    {
        @Override
        public JFileChooser getFileChooser() {
            return SynthFileChooserUIImpl.this.getFileChooser();
        }
        
        @Override
        public BasicDirectoryModel getModel() {
            return SynthFileChooserUIImpl.this.getModel();
        }
        
        @Override
        public JPanel createList() {
            return null;
        }
        
        @Override
        public JPanel createDetailsView() {
            return null;
        }
        
        @Override
        public boolean isDirectorySelected() {
            return SynthFileChooserUIImpl.access$200(SynthFileChooserUIImpl.this);
        }
        
        @Override
        public File getDirectory() {
            return SynthFileChooserUIImpl.access$300(SynthFileChooserUIImpl.this);
        }
        
        @Override
        public Action getChangeToParentDirectoryAction() {
            return SynthFileChooserUIImpl.this.getChangeToParentDirectoryAction();
        }
        
        @Override
        public Action getApproveSelectionAction() {
            return SynthFileChooserUIImpl.this.getApproveSelectionAction();
        }
        
        @Override
        public Action getNewFolderAction() {
            return SynthFileChooserUIImpl.this.getNewFolderAction();
        }
        
        @Override
        public MouseListener createDoubleClickListener(JList list) {
            return SynthFileChooserUIImpl.access$400(SynthFileChooserUIImpl.this, this.getFileChooser(), list);
        }
        
        @Override
        public ListSelectionListener createListSelectionListener() {
            return SynthFileChooserUIImpl.this.createListSelectionListener(this.getFileChooser());
        }
    }
    
    private class DirectoryComboBoxRenderer implements ListCellRenderer<File>
    {
        private ListCellRenderer<? super File> delegate;
        SynthFileChooserUIImpl.IndentIcon ii;
        
        private DirectoryComboBoxRenderer(ListCellRenderer<? super File> delegate) {
            this.ii = new SynthFileChooserUIImpl.IndentIcon();
            this.delegate = delegate;
        }
        
        @Override
        public Component getListCellRendererComponent(JList<? extends File> list, File file, int n, boolean b, boolean b2) {
            Component listCellRendererComponent = this.delegate.getListCellRendererComponent(list, file, n, b, b2);
            assert !(!(listCellRendererComponent instanceof JLabel));
            JLabel label = (JLabel)listCellRendererComponent;
            if (file == null) {
                label.setText("");
                return label;
            }
            label.setText(SynthFileChooserUIImpl.this.getFileChooser().getName(file));
            this.ii.icon = SynthFileChooserUIImpl.this.getFileChooser().getIcon(file);
            this.ii.depth = SynthFileChooserUIImpl.this.directoryComboBoxModel.getDepth(n);
            label.setIcon(this.ii);
            return label;
        }
    }
    
    class IndentIcon implements Icon
    {
        Icon icon;
        int depth;
        
        IndentIcon() {
            this.icon = null;
            this.depth = 0;
        }
        
        @Override
        public void paintIcon(Component component, Graphics graphics, int n, int n2) {
            if (this.icon != null) {
                if (component.getComponentOrientation().isLeftToRight()) {
                    this.icon.paintIcon(component, graphics, n + this.depth * 10, n2);
                }
                else {
                    this.icon.paintIcon(component, graphics, n, n2);
                }
            }
        }
        
        @Override
        public int getIconWidth() {
            return ((this.icon != null) ? this.icon.getIconWidth() : 0) + this.depth * 10;
        }
        
        @Override
        public int getIconHeight() {
            return (this.icon != null) ? this.icon.getIconHeight() : 0;
        }
    }
    
    protected class DirectoryComboBoxModel extends AbstractListModel<File> implements ComboBoxModel<File>
    {
        Vector<File> directories;
        int[] depths;
        File selectedDirectory;
        JFileChooser chooser;
        FileSystemView fsv;
        
        public DirectoryComboBoxModel() {
            this.directories = new Vector();
            this.depths = null;
            this.selectedDirectory = null;
            this.chooser = SynthFileChooserUIImpl.this.getFileChooser();
            this.fsv = this.chooser.getFileSystemView();
            File currentDirectory = SynthFileChooserUIImpl.this.getFileChooser().getCurrentDirectory();
            if (currentDirectory != null) {
                this.addItem(currentDirectory);
            }
        }
        
        public void addItem(File f) {
            if (f == null) {
                return;
            }
            int usesShellFolder = FilePane.usesShellFolder(this.chooser);
            int size = this.directories.size();
            this.directories.clear();
            if (size > 0) {
                this.fireIntervalRemoved(this, 0, size);
            }
            this.directories.addAll(Arrays.asList(usesShellFolder ? ((File[])(File[])ShellFolder.get("fileChooserComboBoxFolders")) : this.fsv.getRoots()));
            File selectedItem;
            try {
                selectedItem = ShellFolder.getNormalizedFile(f);
            }
            catch (IOException ex) {
                selectedItem = f;
            }
            try {
                selectedItem = (selectedItem = (usesShellFolder ? ShellFolder.getShellFolder(selectedItem) : selectedItem));
                Vector o = new Vector(10);
                do {
                    o.addElement(selectedItem);
                } while ((selectedItem = selectedItem.getParentFile()) != null);
                int size2 = o.size();
                int i = 0;
                while (i < size2) {
                    File file = (File)o.get(i);
                    if (this.directories.contains(file)) {
                        int index = this.directories.indexOf(file);
                        for (int j = i - 1; j >= 0; --j) {
                            this.directories.insertElementAt(o.get(j), index + i - j);
                        }
                        break;
                    }
                    ++i;
                }
                this.calculateDepths();
                this.setSelectedItem(selectedItem);
            }
            catch (FileNotFoundException ex2) {
                this.calculateDepths();
            }
            return;
        }
        
        private void calculateDepths() {
            this.depths = new int[this.directories.size()];
            for (int i = 0; i < this.depths.length; ++i) {
                File parentFile = ((File)this.directories.get(i)).getParentFile();
                this.depths[i] = 0;
                if (parentFile != null) {
                    int j = i - 1;
                    while (j >= 0) {
                        if (parentFile.equals(this.directories.get(j))) {
                            this.depths[i] = this.depths[j] + 1;
                            break;
                        }
                        --j;
                    }
                }
            }
        }
        
        public int getDepth(int n) {
            return (this.depths != null && n >= 0 && n < this.depths.length) ? this.depths[n] : 0;
        }
        
        @Override
        public void setSelectedItem(Object o) {
            this.selectedDirectory = (File)o;
            this.fireContentsChanged(this, -1, -1);
        }
        
        @Override
        public Object getSelectedItem() {
            return this.selectedDirectory;
        }
        
        @Override
        public int getSize() {
            return this.directories.size();
        }
        
        @Override
        public File getElementAt(int index) {
            return (File)this.directories.elementAt(index);
        }
    }
    
    protected class DirectoryComboBoxAction extends AbstractAction
    {
        protected DirectoryComboBoxAction() {
            super("DirectoryComboBoxAction");
        }
        
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            SynthFileChooserUIImpl.this.directoryComboBox.hidePopup();
            JComponent directoryComboBox = SynthFileChooserUIImpl.this.getDirectoryComboBox();
            if ((directoryComboBox instanceof JComboBox)) {
                SynthFileChooserUIImpl.this.getFileChooser().setCurrentDirectory((File)((JComboBox)directoryComboBox).getSelectedItem());
            }
        }
    }
    
    public class FilterComboBoxRenderer implements ListCellRenderer<FileFilter>
    {
        private ListCellRenderer<? super FileFilter> delegate;
        
        private FilterComboBoxRenderer(ListCellRenderer<? super FileFilter> delegate) {
            this.delegate = delegate;
        }
        
        @Override
        public Component getListCellRendererComponent(JList<? extends FileFilter> list, FileFilter fileFilter, int n, boolean b, boolean b2) {
            Component listCellRendererComponent = this.delegate.getListCellRendererComponent(list, fileFilter, n, b, b2);
            String description = null;
            if (fileFilter != null) {
                description = fileFilter.getDescription();
            }
            assert !(!(listCellRendererComponent instanceof JLabel));
            if (description != null) {
                ((JLabel)listCellRendererComponent).setText(description);
                return listCellRendererComponent;
            }
            return listCellRendererComponent;
        }
    }
    
    protected class FilterComboBoxModel extends AbstractListModel<FileFilter> implements ComboBoxModel<FileFilter>, PropertyChangeListener
    {
        protected FileFilter[] filters;
        
        protected FilterComboBoxModel() {
            this.filters = SynthFileChooserUIImpl.this.getFileChooser().getChoosableFileFilters();
        }
        
        @Override
        public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
            String propertyName = propertyChangeEvent.getPropertyName();
            if (propertyName == "ChoosableFileFilterChangedProperty") {
                this.filters = (FileFilter[])(FileFilter[])propertyChangeEvent.getNewValue();
                this.fireContentsChanged(this, -1, -1);
            }
            else if (propertyName == "fileFilterChanged") {
                this.fireContentsChanged(this, -1, -1);
            }
        }
        
        @Override
        public void setSelectedItem(Object o) {
            if (o != null) {
                SynthFileChooserUIImpl.this.getFileChooser().setFileFilter((FileFilter)o);
                this.fireContentsChanged(this, -1, -1);
            }
        }
        
        @Override
        public Object getSelectedItem() {
            FileFilter fileFilter = SynthFileChooserUIImpl.this.getFileChooser().getFileFilter();
            boolean n = false;
            if (fileFilter != null) {
                FileFilter[] filters = this.filters;
                for (int length = filters.length, i = 0; i < length; ++i) {
                    if (filters[i] == fileFilter) {
                        n = true;
                    }
                }
                if (n == 0) {
                    SynthFileChooserUIImpl.this.getFileChooser().addChoosableFileFilter(fileFilter);
                }
            }
            return SynthFileChooserUIImpl.this.getFileChooser().getFileFilter();
        }
        
        @Override
        public int getSize() {
            if (this.filters != null) {
                return this.filters.length;
            }
            return 0;
        }
        
        @Override
        public FileFilter getElementAt(int n) {
            if (n > this.getSize() - 1) {
                return SynthFileChooserUIImpl.this.getFileChooser().getFileFilter();
            }
            if (this.filters != null) {
                return this.filters[n];
            }
            return null;
        }
    }
    
    private static class ButtonAreaLayout implements LayoutManager
    {
        private int hGap;
        private int topMargin;
        
        private ButtonAreaLayout() {
            this.hGap = 5;
            this.topMargin = 17;
        }
        
        @Override
        public void addLayoutComponent(String s, Component component) {
        }
        
        @Override
        public void layoutContainer(Container container) {
            Component[] components = container.getComponents();
            if (components != null && components.length > 0) {
                int length = components.length;
                Dimension[] array = new Dimension[length];
                Insets insets = container.getInsets();
                int y = insets.top + this.topMargin;
                int max = 0;
                for (int i = 0; i < length; ++i) {
                    array[i] = components[i].getPreferredSize();
                    max = Math.max(max, array[i].width);
                }
                int left;
                int n;
                if (container.getComponentOrientation().isLeftToRight()) {
                    left = container.getSize().width - insets.left - max;
                    n = this.hGap + max;
                }
                else {
                    left = insets.left;
                    n = -(this.hGap + max);
                }
                for (int j = length - 1; j >= 0; left -= n, --j) {
                    components[j].setBounds(left, y, max, array[j].height);
                }
            }
        }
        
        @Override
        public Dimension minimumLayoutSize(Container container) {
            if (container != null) {
                Component[] components = container.getComponents();
                if (components != null && components.length > 0) {
                    int length = components.length;
                    int max = 0;
                    Insets insets = container.getInsets();
                    int n = this.topMargin + insets.top + insets.bottom;
                    int n2 = insets.left + insets.right;
                    int max2 = 0;
                    for (int i = 0; i < length; ++i) {
                        Dimension preferredSize = components[i].getPreferredSize();
                        max = Math.max(max, preferredSize.height);
                        max2 = Math.max(max2, preferredSize.width);
                    }
                    return new Dimension(n2 + length * max2 + (length - 1) * this.hGap, n + max);
                }
            }
            return new Dimension(0, 0);
        }
        
        @Override
        public Dimension preferredLayoutSize(Container container) {
            return this.minimumLayoutSize(container);
        }
        
        @Override
        public void removeLayoutComponent(Component component) {
        }
    }
    
    private class AlignedLabel extends JLabel
    {
        private SynthFileChooserUIImpl.AlignedLabel[] group;
        private int maxWidth;
        
        AlignedLabel() {
            this.maxWidth = 0;
            this.setAlignmentX(0.0f);
        }
        
        AlignedLabel(String text) {
            super(text);
            this.maxWidth = 0;
            this.setAlignmentX(0.0f);
        }
        
        @Override
        public Dimension getPreferredSize() {
            return new Dimension(this.getMaxWidth() + 11, super.getPreferredSize().height);
        }
        
        private int getMaxWidth() {
            if (this.maxWidth == 0 && this.group != null) {
                int max = 0;
                for (int i = 0; i < this.group.length; ++i) {
                    max = Math.max(this.group[i].getSuperPreferredWidth(), max);
                }
                for (int j = 0; j < this.group.length; ++j) {
                    this.group[j].maxWidth = max;
                }
            }
            return this.maxWidth;
        }
        
        private int getSuperPreferredWidth() {
            return super.getPreferredSize().width;
        }
    }
}
